==> ilias-4.0.3_1.tbz: www/ilias/Services/Registration/exceptions/class.ilRegistrationHashNotFoundException.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2009 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

require_once 'Services/Registration/exceptions/class.ilRegistrationException.php'; 

/** 
* Class for user related exception handling in ILIAS. 
* 
* @author Michael Jansen <mjansen@databay.de>
* @version $Id$ 
* 
*/
class ilRegistrationHashNotFoundException extends ilRegistrationException
{
	/** 
	* Constructor
	* 
	* A message is not optional as in build in class Exception
	* 
	* @access public
	* @param	string	$a_message message
	* 
	*/
	public function __construct($a_message)
	{
	 	parent::__construct($a_message);
	}
}
?>

==> ilias-4.2.5.tbz: www/ilias/Services/Registration/exceptions/class.ilRegistrationHashNotFoundException.php <==
<?php
/*
	+-----------------------------------------------------------------------------+
	| ILIAS open source                                                           |
	+-----------------------------------------------------------------------------+
	| Copyright (c) 1998-2009 ILIAS open source, University of Cologne            |
	|                                                                             |
	| This program is free software; you can redistribute it and/or               |
	| modify it under the terms of the GNU General Public License                 |
	| as published by the Free Software Foundation; either version 2              |
	| of the License, or (at your option) any later version.                      |
	|                                                                             |
	| This program is distributed in the hope that it will be useful,             |
	| but WITHOUT ANY WARRANTY; without even the implied warranty of              |
	| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               |
	| GNU General Public License for more details.                                |
	|                                                                             |
	| You should have received a copy of the GNU General Public License           |
	| along with this program; if not, write to the Free Software                 |
	| Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. |
	+-----------------------------------------------------------------------------+
*/

require_once 'Services/Registration/exceptions/class.ilRegistrationException.php'; 

/** 
* Class for user related exception handling in ILIAS. 
* 
* @author Michael Jansen <mjansen@databay.de>
* @version $Id$ 
* 
*/
class ilRegistrationHashNotFoundException extends ilRegistrationException
{
	/** 
	* Constructor
	* 
	* A message is not optional as in build in class Exception
	* 
	* @access public
	* @param	string	$a_message message
	* @param	integer	$a_code code
	* 
	*/
	public function __construct($a_message, $a_code = 0)
	{
	 	parent::__construct($a_message, $a_code);
	}
}
?>
